package com.chinaitop.depot.device.controller;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.chinaitop.depot.device.model.BusinessImAsset;
import com.chinaitop.depot.device.model.BusinessImAssetExample;
import com.chinaitop.depot.device.service.BusinessImAssetService;
import com.chinaitop.depot.utils.ParameterUtil;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;


import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 
 */

@RestController
@RequestMapping(value= "/businessImAsset")
@Api(value= "BusinessImAssetController", description = "资产管理")
public class BusinessImAssetController {

	@Resource
	private BusinessImAssetService businessImAssetService;
	
	
	
	 /**
     * 资产管理列表
	 * @throws Exception 
     */
	@RequestMapping(value = "/getList",produces = MediaType.APPLICATION_JSON_VALUE,method=RequestMethod.GET)
    @ApiOperation(value="查询资产管理列表信息", notes = "查询资产管理列表信息，支持分页")
  	@ApiImplicitParams({
  			@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
  			@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
  			@ApiImplicitParam(name = "assetCode", value = "资产编号", paramType = "query"),
  			@ApiImplicitParam(name = "assetStatus", value = "资产状态", paramType = "query")

  	})
    public PageInfo<BusinessImAsset> getList(HttpServletRequest request,Integer pageNum, Integer pageSize, String assetCode, Integer assetStatus,Integer orgId) throws Exception{
    	
		BusinessImAssetExample businessImAssetExample=new BusinessImAssetExample();
		BusinessImAssetExample.Criteria criteria=businessImAssetExample.createCriteria();
		
    	if(ParameterUtil.isnotnull(assetCode)){
    		criteria.andAssetCodeLike(assetCode);
    	}
    	if(ParameterUtil.isnotnull(assetStatus)){
    		criteria.andAssetStatusEqualTo(assetStatus);
    	}
    	if(ParameterUtil.isnotnull(orgId)){
    		criteria.andOrgIdEqualTo(orgId);
    	}

        //排序
    	businessImAssetExample.setOrderByClause("id desc");
        
        if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }
        List<BusinessImAsset> list = businessImAssetService.getList(businessImAssetExample);
        PageInfo<BusinessImAsset> pageInfo = new PageInfo<BusinessImAsset>(list);
        return pageInfo;
    }

    
    /**
     * 根据主键id删除数据
     */
	 @RequestMapping(value="/remove", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
	 @ApiOperation(value="删除数据", notes = "根据id删除数据")
	 @ApiImplicitParams({
	   	 @ApiImplicitParam(name = "id", value = "id", paramType = "form"),
	 })    
	 public Map<String, Object> remove(Integer id){
        Map<String,Object> retMap = new HashMap<String,Object>();
        businessImAssetService.remove(id);
        retMap.put("msg","success");
        return retMap;
    }
	
    /**
     * 新增和修改的数据进行保存
     */
	 @RequestMapping(value="/save",produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
	 @ApiOperation(value="保存数据", notes = "保存")
	
    public Map<String, Object> save(@RequestBody BusinessImAsset businessImAsset) {
        Map<String, Object> modelMap = new HashMap<>();
        // JSON字符串转对象
        ObjectMapper mapper = new ObjectMapper();
        try {
        	businessImAssetService.save(businessImAsset);
            modelMap.put("status", "success");
        } catch (Exception e) {
            modelMap.put("status", "error");
            modelMap.put("msg", "保存失败！");
            e.printStackTrace();
        }
        return modelMap;
    }

	   
	 
    /**
     * 根据id加载对应数据
     */
	 @RequestMapping(value ="/loadDataById", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	 @ApiOperation(value="查询数据", notes = "根据id查询数据")
	 @ApiImplicitParams({
		  @ApiImplicitParam(name = "id", value = "id", paramType = "query"),
	 })
    public BusinessImAsset loadDataById(int id){
	   if(id != 0) {
           return  businessImAssetService.loadDataById(id);
       }
       return new BusinessImAsset();
    }
   
	 
	 /**
	  * 资产编号获取
	  */
	@RequestMapping(value ="/getAssetCode", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="资产编号获取", notes = "资产编号获取")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "orgId", value = "单位id", paramType = "query")
	})
    public String getAssetCode(Integer orgId){
		
	   return businessImAssetService.getAssetCode(orgId);
    }
	
}
