package com.chinaitop.depot.device.controller;


import com.chinaitop.depot.device.model.BusinessImAsset;
import com.chinaitop.depot.device.model.BusinessImPurchaseSale;
import com.chinaitop.depot.device.model.param.BusinessImPurchaseSaleAddParam;
import com.chinaitop.depot.device.model.param.BusinessImPurchaseSaleEditParam;
import com.chinaitop.depot.device.model.param.BusinessImPurchaseSalePageParam;
import com.chinaitop.depot.device.service.BusinessImPurchaseSaleService;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

/**
 * <p>
 * 智能管理-综合业务管理-采购销售管理表 前端控制器
 * </p>
 *
 * @author root
 * @since 2024-06-06
 */
@RestController
@RequestMapping("/business-im-purchase-sale")
@Api(value= "BusinessImPurchaseSaleController", description = "综合业务管理-采购销售管理")
@CrossOrigin
public class BusinessImPurchaseSaleController {

    @Autowired
    private BusinessImPurchaseSaleService businessImPurchaseSaleService;

    @GetMapping("/getList")
    @ApiOperation(value = "查询 采购销售管理 信息列表", notes = "查询 采购销售管理 信息列表")
    public ResponseEntity<PageInfo<BusinessImPurchaseSale>> getList( BusinessImPurchaseSalePageParam pageParam) {

        return ResponseEntity.ok(businessImPurchaseSaleService.getList(pageParam));
    }

/*    @PostMapping("/saveAndUpdate")
    @ApiOperation(value="采购销售管理-保存/修改", notes = "保存/修改")
    public Map<String, Object> save(@RequestBody String businessImPurchaseSaleJson) {
        Map<String, Object> modelMap = new HashMap<>();
        // JSON字符串转对象
        ObjectMapper mapper = new ObjectMapper();
        String replace = businessImPurchaseSaleJson.replace("+", " ");
        try {
            BusinessImPurchaseSale businessImPurchaseSale = (BusinessImPurchaseSale)mapper.readValue(replace, BusinessImPurchaseSale.class);
            businessImPurchaseSaleService.saveOrUpdateBusinessImPurchaseSale(businessImPurchaseSale);
            modelMap.put("status", "success");
        } catch (IOException e) {
            modelMap.put("status", "error");
            modelMap.put("msg", "保存/修改失败！");
            e.printStackTrace();
        }
        return modelMap;
    }*/

    @PostMapping("/saveAndUpdate")
    @ApiOperation(value="采购销售管理-保存/修改", notes = "保存/修改")
    public Map<String, Object> save(@RequestBody BusinessImPurchaseSale businessImPurchaseSale) {
        Map<String, Object> modelMap = new HashMap<>();
        try {
            businessImPurchaseSaleService.saveOrUpdateBusinessImPurchaseSale(businessImPurchaseSale);
            modelMap.put("status", "success");
        } catch (Exception e) {
            modelMap.put("status", "error");
            modelMap.put("msg", "保存/修改失败！");
            e.printStackTrace();
        }
        return modelMap;
    }

  /*  @PutMapping("/update")
    @ApiOperation(value = "采购销售管理-修改", notes = "修改")
    public ResponseEntity update(@Validated @RequestBody BusinessImPurchaseSaleEditParam param) {
        return ResponseEntity.ok(businessImPurchaseSaleService.updateData(param));
    }*/

    @DeleteMapping("/delete/{id}")
    @ApiOperation(value = "采购销售管理-删除", notes = "id删除")
    public ResponseEntity delete(@PathVariable("id") String id) {
        return ResponseEntity.ok(businessImPurchaseSaleService.deleteData(id));
    }

    @GetMapping("/getById")
    @ApiOperation(value = "采购销售管理-详情", notes = "id获取详情")
    public ResponseEntity<BusinessImPurchaseSale> getById(String id) {
        return ResponseEntity.ok(businessImPurchaseSaleService.getById(id));
    }

}
