package com.chinaitop.depot.device.controller;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.apache.poi.ss.formula.functions.T;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.chinaitop.depot.device.model.StorageJsgl;
import com.chinaitop.depot.device.service.StorageJsglService;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping(value="/storageJsgl")
@Api(value= "StorageJsglController", description = "结算管理")
public class StorageJsglController {

	@Resource
	private StorageJsglService storageJsglService;

	@RequestMapping(value = "/getPageInfoList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "结算管理列表查询", notes = "支持分页")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
        @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
        @ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "query"),
        @ApiImplicitParam(name = "jslx", value = "结算类型(0:入库,1:出库)", paramType = "query"),
        @ApiImplicitParam(name = "houseId", value = "仓房", paramType = "query"),
        @ApiImplicitParam(name = "warehouseId", value = "货位", paramType = "query")
    })
    public PageInfo<StorageJsgl> getPageInfoList(Integer pageNum, Integer pageSize, String jslx, 
    		Integer houseId, Integer warehouseId, Integer orgId) {

        if (pageNum != null && pageSize != null) PageHelper.startPage(pageNum, pageSize);

        List<StorageJsgl> list = null;
		try {
			list = storageJsglService.findByCondition(houseId, warehouseId, orgId, jslx);
		} catch (Exception e) {
			e.printStackTrace();
		}

        PageInfo<StorageJsgl> pageInfo = new PageInfo<StorageJsgl>(list);
        return pageInfo;
    }
	
	@RequestMapping(value = "/save", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "结算管理保存", notes = "")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "jsglJson", value = "数据对象", paramType = "form")
    })
    public Map<String, Object> save(String jsglJson) {

        Map<String, Object> map = new HashMap<>();

		try {
			ObjectMapper mapper = new ObjectMapper();
			StorageJsgl storageJsgl = mapper.readValue(jsglJson, StorageJsgl.class);
			storageJsglService.saveOrUpdate(storageJsgl);
			map.put("status", "200");
		} catch (Exception e) {
			map.put("status", "500");
			e.printStackTrace();
		}

        return map;
    }
	
	@RequestMapping(value = "/findByStorageJsgl", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "按主键ID查询一条结算管理数据", notes = "")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "id", value = "主键ID", paramType = "query")
    })
    public StorageJsgl findByStorageJsgl(String id) {

		StorageJsgl storageJsgl = null;
		try {
			if (null != id) {
				storageJsgl = storageJsglService.findByParmaryKey(id);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}

        return storageJsgl;
    }

	@RequestMapping(value = "/removeJsgl", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "删除一条结算管理", notes = "")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "id", value = "主键ID", paramType = "form")
    })
    public Map<String, Object> removeJsgl(String id) {

        Map<String, Object> map = new HashMap<>();

		try {
			storageJsglService.removeStorageJsgl(id);
			map.put("status", "200");
		} catch (Exception e) {
			map.put("status", "500");
			e.printStackTrace();
		}

        return map;
    }

	@RequestMapping(value = "/getHtData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "获取当前粮库的合同信息", notes = "")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "query"),
        @ApiImplicitParam(name = "jslx", value = "结算类型(0:入库,1:出库)", paramType = "query")
    })
	public List<T> getHtData(Integer orgId, String jslx) {
		
		return null;
	}
}
