package com.chinaitop.depot.device.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.chinaitop.depot.device.mapper.BusinessImPurchaseSaleMapper;
import com.chinaitop.depot.device.model.BusinessImPurchaseSale;
import com.chinaitop.depot.device.model.param.BusinessImPurchaseSaleAddParam;
import com.chinaitop.depot.device.model.param.BusinessImPurchaseSaleEditParam;
import com.chinaitop.depot.device.model.param.BusinessImPurchaseSalePageParam;
import com.chinaitop.depot.device.service.BusinessImPurchaseSaleService;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 智能管理-综合业务管理-采购销售管理表 服务实现类
 * </p>
 *
 * @author root
 * @since 2024-06-06
 */
@Service
public class BusinessImPurchaseSaleServiceImpl extends ServiceImpl<BusinessImPurchaseSaleMapper, BusinessImPurchaseSale> implements BusinessImPurchaseSaleService {
    private static Map<String, Integer> sequenceNumbers = new HashMap<>(); // 映射：仓房代码到顺序号
    private static final int MAX_SEQUENCE_NUMBER = 10000; // 顺序号的最大值
    private static final String DATE_FORMAT = "yyyyMMdd";
    private static final DateTimeFormatter DATE_FORMATTER = DateTimeFormatter.ofPattern(DATE_FORMAT);


    @Autowired
    private BusinessImPurchaseSaleMapper businessImPurchaseSaleMapper;


    @Override
    public PageInfo<BusinessImPurchaseSale> getList(BusinessImPurchaseSalePageParam pageParam) {

        PageHelper.startPage(pageParam.getPageNum(), pageParam.getPageSize());

        List<BusinessImPurchaseSale> list= businessImPurchaseSaleMapper.getList(pageParam.getPurchaseCode(), pageParam.getPurchasePlanName(),pageParam.getOrgId());

        PageInfo<BusinessImPurchaseSale> page = new PageInfo<>(list);
        return page;

    }


    @Override
    public int saveData(BusinessImPurchaseSaleAddParam param) {

        BusinessImPurchaseSale businessImPurchaseSale = new BusinessImPurchaseSale();
        BeanUtils.copyProperties(param, businessImPurchaseSale);

        //生成资产编号
        sequenceNumbers.putIfAbsent("CG", 0);
        // 增加当前货位的顺序号，并在达到最大值时重置为0
        int sequenceNumber = (sequenceNumbers.get("CG") + 1) % MAX_SEQUENCE_NUMBER;
        sequenceNumbers.put("CG", sequenceNumber);
        // 确保顺序号是4位数
        String formattedSequenceNumber = String.format("%03d", sequenceNumber);
        // 获取当前日期并格式化为yyyyMMdd
        String currentDate = LocalDate.now().format(DATE_FORMATTER);
        // 合并、日期和顺序号
        String assetCode = "CG" +currentDate + formattedSequenceNumber;
        businessImPurchaseSale.setPurchaseCode(assetCode);
        businessImPurchaseSale.setCreatedate(new Date());
        businessImPurchaseSale.setUpdatedate(new Date());

        try {
            // businessImPurchaseSaleMapper.insertBusinessImPurchaseSale(businessImPurchaseSale);
            return businessImPurchaseSaleMapper.insert(businessImPurchaseSale);
        } catch (Exception e) {
            throw new RuntimeException("新增数据失败" + e.getMessage());
        }

    }

    @Override
    public int updateData(BusinessImPurchaseSaleEditParam param) {
        BusinessImPurchaseSale businessImPurchaseSale = new BusinessImPurchaseSale();
        BeanUtils.copyProperties(param, businessImPurchaseSale);
        businessImPurchaseSale.setUpdatedate(new Date());
        try {
            return businessImPurchaseSaleMapper.updateById(businessImPurchaseSale);
        } catch (Exception e) {
            throw new RuntimeException("修改数据失败" + e.getMessage());
        }

    }


    @Override
    public void saveOrUpdateBusinessImPurchaseSale(BusinessImPurchaseSale businessImPurchaseSale) {

        if (businessImPurchaseSale.getId()==null){

            //生成资产编号
            sequenceNumbers.putIfAbsent("CG", 0);
            // 增加当前货位的顺序号，并在达到最大值时重置为0
            int sequenceNumber = (sequenceNumbers.get("CG") + 1) % MAX_SEQUENCE_NUMBER;
            sequenceNumbers.put("CG", sequenceNumber);
            // 确保顺序号是4位数
            String formattedSequenceNumber = String.format("%03d", sequenceNumber);
            // 获取当前日期并格式化为yyyyMMdd
            String currentDate = LocalDate.now().format(DATE_FORMATTER);
            // 合并、日期和顺序号
            String assetCode = "CG" +currentDate + formattedSequenceNumber;
            businessImPurchaseSale.setPurchaseCode(assetCode);
            businessImPurchaseSale.setCreatedate(new Date());


            try {
                // businessImPurchaseSaleMapper.insertBusinessImPurchaseSale(businessImPurchaseSale);
                 businessImPurchaseSaleMapper.insert(businessImPurchaseSale);
            } catch (Exception e) {
                throw new RuntimeException("新增数据失败" + e.getMessage());
            }
        }else {
            businessImPurchaseSale.setUpdatedate(new Date());
            businessImPurchaseSaleMapper.updateById(businessImPurchaseSale);
        }
    }

    @Override
    public int deleteData(String id) {

        return businessImPurchaseSaleMapper.deleteById(id);
    }

    /**
     * @author: hujianchun
     * @Description:
     * @param:
     * @return: 采购销售管理-详情
     */
    @Override
    public BusinessImPurchaseSale getById(String id) {
        return businessImPurchaseSaleMapper.getById(id);
    }
}
